@@ -83,7 +83,7 @@ class CLIParser:
         )
         parser.add_argument(
             "--variable",
-            "-V",
+            "-v",
             type=str,
             required=False,
             action="append",
@@ -164,7 +164,7 @@ class CLIParser:
             )
             parser.add_argument(
                 "--csv-file",
-                "-v",
+                "-V",
                 type=str,
                 required=False,
                 action="append",
@@ -178,13 +178,6 @@ class CLIParser:
                 required=False,
                 help="process CSV variable substitutions only and output intermediate JSON",
             )
-            parser.add_argument(
-                "--yes",
-                "-y",
-                action="store_true",
-                required=False,
-                help="proceed without requiring user confirmation",
-            )
 
         if any(module in sys.argv[0] for module in ["provision", "instantiate"]):
             parser.add_argument(
@@ -362,6 +355,13 @@ class CLIParser:
                 help="the compute requirement definition",
                 metavar="<compute_requirement.json>",
             )
+            parser.add_argument(
+                "--report",
+                "-r",
+                action="store_true",
+                required=False,
+                help="report on a Dynamic Template test run",
+            )
 
         if "admin" in sys.argv[0]:
             parser.add_argument(
@@ -548,6 +548,10 @@ class CLIParser:
     def content_path(self) -> Optional[str]:
         return self.args.content_path
 
+    @property
+    def report(self) -> Optional[bool]:
+        return self.args.report
+
 
 def lookup_module_description(module_name: str) -> Optional[str]:
     """
