@@ -50,7 +50,9 @@ for key, value in os.environ.items():
     if key.startswith(ENV_VAR_PREFIX):
         key = key[len(ENV_VAR_PREFIX) :]
         MUSTACHE_SUBSTITUTIONS[key] = value
-        print_log(f"Adding user-defined Mustache substitution: '{key}' = '{value}'")
+        print_log(
+            f"Adding environment-defined variable substitution: '{key}' = '{value}'"
+        )
 
 # Directives from the command line (take precedence over environment variables)
 if ARGS_PARSER.variables is not None:
@@ -59,7 +61,7 @@ if ARGS_PARSER.variables is not None:
         if len(key_value) == 2:
             MUSTACHE_SUBSTITUTIONS[key_value[0]] = key_value[1]
             print_log(
-                f"Adding user-defined Mustache substitution: "
+                f"Adding command-line-defined variable substitution: "
                 f"'{key_value[0]}' = '{key_value[1]}'"
             )
         else:
@@ -72,7 +74,8 @@ if ARGS_PARSER.variables is not None:
 
 def add_substitutions(subs: Dict):
     """
-    Add a dictionary of substitutions. Do not overwrite existing values.
+    Add a dictionary of substitutions. Do not overwrite existing values, but
+    resolve remaining variables if possible.
     """
     global MUSTACHE_SUBSTITUTIONS
     subs.update(MUSTACHE_SUBSTITUTIONS)
